# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'FileType'
        db.create_table('docbow_filetype', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(unique=True, max_length=128)),
        ))
        db.send_create_signal('docbow', ['FileType'])

        # Adding model 'Content'
        db.create_table('docbow_content', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('description', self.gf('django.db.models.fields.CharField')(unique=True, max_length=128)),
        ))
        db.send_create_signal('docbow', ['Content'])

        # Adding model 'Document'
        db.create_table('docbow_document', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('sender', self.gf('django.db.models.fields.related.ForeignKey')(related_name='documents_sent', to=orm['auth.User'])),
            ('date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now)),
            ('filetype', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['docbow.FileType'])),
            ('comment', self.gf('django.db.models.fields.TextField')(blank=True)),
        ))
        db.send_create_signal('docbow', ['Document'])

        # Adding M2M table for field to_user on 'Document'
        db.create_table('docbow_document_to_user', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('document', models.ForeignKey(orm['docbow.document'], null=False)),
            ('user', models.ForeignKey(orm['auth.user'], null=False))
        ))
        db.create_unique('docbow_document_to_user', ['document_id', 'user_id'])

        # Adding M2M table for field to_list on 'Document'
        db.create_table('docbow_document_to_list', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('document', models.ForeignKey(orm['docbow.document'], null=False)),
            ('mailinglist', models.ForeignKey(orm['docbow.mailinglist'], null=False))
        ))
        db.create_unique('docbow_document_to_list', ['document_id', 'mailinglist_id'])

        # Adding model 'AttachedFile'
        db.create_table('docbow_attachedfile', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=128)),
            ('content', self.gf('django.db.models.fields.files.FileField')(max_length=100)),
            ('document', self.gf('django.db.models.fields.related.ForeignKey')(related_name='attached_files', to=orm['docbow.Document'])),
        ))
        db.send_create_signal('docbow', ['AttachedFile'])

        # Adding model 'MailingList'
        db.create_table('docbow_mailinglist', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=128)),
        ))
        db.send_create_signal('docbow', ['MailingList'])

        # Adding M2M table for field members on 'MailingList'
        db.create_table('docbow_mailinglist_members', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('mailinglist', models.ForeignKey(orm['docbow.mailinglist'], null=False)),
            ('user', models.ForeignKey(orm['auth.user'], null=False))
        ))
        db.create_unique('docbow_mailinglist_members', ['mailinglist_id', 'user_id'])

        # Adding model 'Mailbox'
        db.create_table('docbow_mailbox', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('owner', self.gf('django.db.models.fields.related.ForeignKey')(related_name='documents', to=orm['auth.User'])),
            ('document', self.gf('django.db.models.fields.related.ForeignKey')(related_name='mailboxes', to=orm['docbow.Document'])),
            ('seen', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('deleted', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('outbox', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('date', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, auto_now_add=True, blank=True)),
        ))
        db.send_create_signal('docbow', ['Mailbox'])

        # Adding model 'SendingLimitation'
        db.create_table('docbow_sendinglimitation', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('mailing_list', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['docbow.MailingList'], unique=True)),
        ))
        db.send_create_signal('docbow', ['SendingLimitation'])

        # Adding M2M table for field filetypes on 'SendingLimitation'
        db.create_table('docbow_sendinglimitation_filetypes', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('sendinglimitation', models.ForeignKey(orm['docbow.sendinglimitation'], null=False)),
            ('filetype', models.ForeignKey(orm['docbow.filetype'], null=False))
        ))
        db.create_unique('docbow_sendinglimitation_filetypes', ['sendinglimitation_id', 'filetype_id'])

        # Adding M2M table for field lists on 'SendingLimitation'
        db.create_table('docbow_sendinglimitation_lists', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('sendinglimitation', models.ForeignKey(orm['docbow.sendinglimitation'], null=False)),
            ('mailinglist', models.ForeignKey(orm['docbow.mailinglist'], null=False))
        ))
        db.create_unique('docbow_sendinglimitation_lists', ['sendinglimitation_id', 'mailinglist_id'])


    def backwards(self, orm):
        
        # Deleting model 'FileType'
        db.delete_table('docbow_filetype')

        # Deleting model 'Content'
        db.delete_table('docbow_content')

        # Deleting model 'Document'
        db.delete_table('docbow_document')

        # Removing M2M table for field to_user on 'Document'
        db.delete_table('docbow_document_to_user')

        # Removing M2M table for field to_list on 'Document'
        db.delete_table('docbow_document_to_list')

        # Deleting model 'AttachedFile'
        db.delete_table('docbow_attachedfile')

        # Deleting model 'MailingList'
        db.delete_table('docbow_mailinglist')

        # Removing M2M table for field members on 'MailingList'
        db.delete_table('docbow_mailinglist_members')

        # Deleting model 'Mailbox'
        db.delete_table('docbow_mailbox')

        # Deleting model 'SendingLimitation'
        db.delete_table('docbow_sendinglimitation')

        # Removing M2M table for field filetypes on 'SendingLimitation'
        db.delete_table('docbow_sendinglimitation_filetypes')

        # Removing M2M table for field lists on 'SendingLimitation'
        db.delete_table('docbow_sendinglimitation_lists')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'docbow.attachedfile': {
            'Meta': {'object_name': 'AttachedFile'},
            'content': ('django.db.models.fields.files.FileField', [], {'max_length': '100'}),
            'document': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'attached_files'", 'to': "orm['docbow.Document']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '128'})
        },
        'docbow.content': {
            'Meta': {'ordering': "['description']", 'object_name': 'Content'},
            'description': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '128'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        'docbow.document': {
            'Meta': {'ordering': "['-date']", 'object_name': 'Document'},
            'comment': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'filetype': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['docbow.FileType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'sender': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'documents_sent'", 'to': "orm['auth.User']"}),
            'to_list': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['docbow.MailingList']", 'null': 'True', 'blank': 'True'}),
            'to_user': ('django.db.models.fields.related.ManyToManyField', [], {'blank': 'True', 'related_name': "'directly_received_documents'", 'null': 'True', 'symmetrical': 'False', 'to': "orm['auth.User']"})
        },
        'docbow.filetype': {
            'Meta': {'ordering': "['name']", 'object_name': 'FileType'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '128'})
        },
        'docbow.mailbox': {
            'Meta': {'ordering': "['-date']", 'object_name': 'Mailbox'},
            'date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'}),
            'deleted': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'document': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'mailboxes'", 'to': "orm['docbow.Document']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'outbox': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'owner': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'documents'", 'to': "orm['auth.User']"}),
            'seen': ('django.db.models.fields.BooleanField', [], {'default': 'False'})
        },
        'docbow.mailinglist': {
            'Meta': {'ordering': "['name']", 'object_name': 'MailingList'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'members': ('django.db.models.fields.related.ManyToManyField', [], {'blank': 'True', 'related_name': "'mailing_lists'", 'null': 'True', 'symmetrical': 'False', 'to': "orm['auth.User']"}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '128'})
        },
        'docbow.sendinglimitation': {
            'Meta': {'object_name': 'SendingLimitation'},
            'filetypes': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'related_name': "'filetype_limitation'", 'blank': 'True', 'to': "orm['docbow.FileType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'lists': ('django.db.models.fields.related.ManyToManyField', [], {'related_name': "'lists_limitation'", 'symmetrical': 'False', 'to': "orm['docbow.MailingList']"}),
            'mailing_list': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['docbow.MailingList']", 'unique': 'True'})
        }
    }

    complete_apps = ['docbow']
