import rfc3161
import os.path

from django.utils import simplejson

from . import app_settings

PROVIDERS = {
        'certum': {
            'url': 'http://time.certum.pl',
            'certificate': file(os.path.join(os.path.dirname(__file__), 'certum_certificate.crt')).read(),
        },
        'fedict': {
            'url': 'http://tsa.belgium.be/connect',
            'certificate': file(os.path.join(os.path.dirname(__file__), 'fedict.crt')).read(),
        },
        'e_szigno': {
            'url': 'https://teszt.e-szigno.hu:440/tsa',
            'certificate': file(os.path.join(os.path.dirname(__file__), 'e_szigno_test_tsa2.crt')).read(),
            'username': 'teszt',
            'password': 'teszt',
            'hashname': 'sha256',
        },
}

class TimestampingError(RuntimeError):
    pass

def timestamp(content):
    kwargs = PROVIDERS[app_settings.TIMESTAMP_PROVIDER]
    timestamper = rfc3161.RemoteTimestamper(**kwargs)
    try:
        return timestamper(data=content)
    except Exception, e:
        raise TimestampingError(e)

def timestamp_json(json_dict):
    s = simplejson.dumps(json_dict)
    if s[-1] != '}':
        raise ValueError("timestamp_json takes a dictionnary as argument: %s" % s)
    tst, error = timestamp(s)
    try:
        dt = rfc3161.get_timestamp(tst)
    except ValueError:
        dt = None
    if tst:
        return s[:-1] + ',"timestamp": "%s"}' % tst.encode('base64').strip(), dt
    else:
        raise TimestampingError(error)

def check_timestamp_json(content, certificate):
    content, tst = content.rsplit(',"timestamp": "', 1)
    content += '}'
    tst = tst[:-2].decode('base64')
    return rfc3161.check_timestamp(tst, certificate, data=content)

