#!env python

from setuptools import setup, find_packages
from setuptools.command.install_lib import install_lib as _install_lib
from distutils.command.build import build as _build
from distutils.command.sdist import sdist  as _sdist
from distutils.cmd import Command

class compile_translations(Command):
    description = 'compile message catalogs to MO files via django compilemessages'
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        import os
        import sys
        from django.core.management.commands.compilemessages import \
            compile_messages
        for path in ['docbow_project']:
            if not os.path.exists(os.path.join(path, 'locale')):
                continue
            curdir = os.getcwd()
            os.chdir(os.path.realpath(path))
            compile_messages(sys.stderr)
            os.chdir(curdir)

class build(_build):
    sub_commands = [('compile_translations', None)] + _build.sub_commands

class sdist(_sdist):
    sub_commands = [('compile_translations', None)] + _sdist.sub_commands

class install_lib(_install_lib):
    def run(self):
        self.run_command('compile_translations')
        _install_lib.run(self)


def get_version():
    import glob
    import re
    import os

    version = None
    for d in glob.glob('*'):
        if not os.path.isdir(d):
            continue
        module_file = os.path.join(d, '__init__.py')
        if not os.path.exists(module_file):
            continue
        for v in re.findall("""__version__ *= *['"](.*)['"]""",
                open(module_file).read()):
            assert version is None
            version = v
        if version:
            break
    assert version is not None
    if os.path.exists('.git'):
        import subprocess
        p = subprocess.Popen(['git','describe','--dirty','--match=v*'],
                stdout=subprocess.PIPE)
        result = p.communicate()[0]
        assert p.returncode == 0, 'git returned non-zero'
        new_version = result.split()[0][1:]
        assert not new_version.endswith('-dirty'), 'git workdir is not clean'
        assert new_version.split('-')[0] == version, '__version__ must match the last git annotated tag'
        version = new_version.replace('-', '.')
    return version

setup(name='docbow',
        version='1.0',
        license='AGPL 3.0',
        description='Document box for the Wallon  Parliament',
        url='https://dev.entrouvert.org/projects/docbow-pub/',
        author="Entr'ouvert",
        author_email='info@entrouvert.com',
        maintainer='Benjamin Dauvergne',
        maintainer_email='bdauvergne@entrouvert.com',
        scripts=('docbow-ctl',),
        package_data={
            '': [
                 'templates/**.html',
                 'templates/**.txt',
                 'static/**.png',
                 'static/**.gif',
                 'static/**.css',
                 'static/**.js',
                 'locale/**.mo', 
                 'fixtures/*.json',
                ]
        },
        packages=find_packages(),
        install_requires=[
              'Django>=1.5,<1.6',
              'South<0.8.0',
              'django-debug-toolbar<0.9.0',
              'django-grappelli<2.5.0',
              'django-tinymce<1.6.0',
              'django-crispy-forms>=1.3,<1.4',
              'django-auth-ldap<1.1',
              'python-ldap<3.0.0',
              'BeautifulSoup<3.3.0',
              'M2Crypto<1.0.0',
              'pyasn1<1.0.0',
              'pyasn1-modules<1.0.0',
              'rfc3161==0.1.9',
              'gunicorn',
              'django_journal<2.0.0',
              'django-picklefield==0.3.0',
              'python-entrouvert>=2',
              'django-tables2==0.13.0',
              'raven',
        ],
        setup_requires=[
              'Django>=1.5,<1.6',
        ],
        dependency_links = [
            'git+http://repos.entrouvert.org/python-entrouvert.git/#egg=entrouvert-1.1.9999',
        ],
        cmdclass={'build': build, 'install_lib': install_lib,
            'compile_translations': compile_translations,
            'sdist': sdist})
